==> kubernetes-model-1.0.34-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerStateFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class ContainerStateFluentImpl<T extends ContainerStateFluent<T>> extends BaseFluent<T> implements ContainerStateFluent<T>{

     VisitableBuilder<ContainerStateRunning, ?> running;     VisitableBuilder<ContainerStateTerminated, ?> terminated;     VisitableBuilder<ContainerStateWaiting, ?> waiting;     Map<String, Object> additionalProperties = new HashMap();
public ContainerStateFluentImpl(){
    
}
public ContainerStateFluentImpl( ContainerState instance ){
    this.withRunning(instance.getRunning()); this.withTerminated(instance.getTerminated()); this.withWaiting(instance.getWaiting()); 
}

    public ContainerStateRunning getRunning(){
    return this.running!=null?this.running.build():null;
    }
    public T withRunning( ContainerStateRunning running){
    if (running!=null){ this.running= new ContainerStateRunningBuilder(running); _visitables.add(this.running);} return (T) this;
    }
    public RunningNested<T> withNewRunning(){
    return new RunningNestedImpl<T>();
    }
    public RunningNested<T> withNewRunningLike( ContainerStateRunning item){
    return new RunningNestedImpl<T>(item);
    }
    public RunningNested<T> editRunning(){
    return withNewRunningLike(getRunning());
    }
    public T withNewRunning( String startedAt){
    return withRunning(new ContainerStateRunning(startedAt));
    }
    public ContainerStateTerminated getTerminated(){
    return this.terminated!=null?this.terminated.build():null;
    }
    public T withTerminated( ContainerStateTerminated terminated){
    if (terminated!=null){ this.terminated= new ContainerStateTerminatedBuilder(terminated); _visitables.add(this.terminated);} return (T) this;
    }
    public TerminatedNested<T> withNewTerminated(){
    return new TerminatedNestedImpl<T>();
    }
    public TerminatedNested<T> withNewTerminatedLike( ContainerStateTerminated item){
    return new TerminatedNestedImpl<T>(item);
    }
    public TerminatedNested<T> editTerminated(){
    return withNewTerminatedLike(getTerminated());
    }
    public ContainerStateWaiting getWaiting(){
    return this.waiting!=null?this.waiting.build():null;
    }
    public T withWaiting( ContainerStateWaiting waiting){
    if (waiting!=null){ this.waiting= new ContainerStateWaitingBuilder(waiting); _visitables.add(this.waiting);} return (T) this;
    }
    public WaitingNested<T> withNewWaiting(){
    return new WaitingNestedImpl<T>();
    }
    public WaitingNested<T> withNewWaitingLike( ContainerStateWaiting item){
    return new WaitingNestedImpl<T>(item);
    }
    public WaitingNested<T> editWaiting(){
    return withNewWaitingLike(getWaiting());
    }
    public T withNewWaiting( String reason){
    return withWaiting(new ContainerStateWaiting(reason));
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ContainerStateFluentImpl that = (ContainerStateFluentImpl) o;
if (running != null ? !running.equals(that.running) :that.running != null) return false;
if (terminated != null ? !terminated.equals(that.terminated) :that.terminated != null) return false;
if (waiting != null ? !waiting.equals(that.waiting) :that.waiting != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class RunningNestedImpl<N> extends ContainerStateRunningFluentImpl<RunningNested<N>> implements RunningNested<N>{

        private final ContainerStateRunningBuilder builder;
    
             RunningNestedImpl (){
        this.builder = new ContainerStateRunningBuilder(this);
        }
             RunningNestedImpl ( ContainerStateRunning item){
        this.builder = new ContainerStateRunningBuilder(this, item);
        }
    
            public N and(){
            return (N) ContainerStateFluentImpl.this.withRunning(builder.build());
        }
            public N endRunning(){
            return and();
        }
    
}
    public class TerminatedNestedImpl<N> extends ContainerStateTerminatedFluentImpl<TerminatedNested<N>> implements TerminatedNested<N>{

        private final ContainerStateTerminatedBuilder builder;
    
             TerminatedNestedImpl ( ContainerStateTerminated item){
        this.builder = new ContainerStateTerminatedBuilder(this, item);
        }
             TerminatedNestedImpl (){
        this.builder = new ContainerStateTerminatedBuilder(this);
        }
    
            public N endTerminated(){
            return and();
        }
            public N and(){
            return (N) ContainerStateFluentImpl.this.withTerminated(builder.build());
        }
    
}
    public class WaitingNestedImpl<N> extends ContainerStateWaitingFluentImpl<WaitingNested<N>> implements WaitingNested<N>{

        private final ContainerStateWaitingBuilder builder;
    
             WaitingNestedImpl (){
        this.builder = new ContainerStateWaitingBuilder(this);
        }
             WaitingNestedImpl ( ContainerStateWaiting item){
        this.builder = new ContainerStateWaitingBuilder(this, item);
        }
    
            public N and(){
            return (N) ContainerStateFluentImpl.this.withWaiting(builder.build());
        }
            public N endWaiting(){
            return and();
        }
    
}


}

==> kubernetes-model-1.0.41-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerStateFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class ContainerStateFluentImpl<T extends ContainerStateFluent<T>> extends BaseFluent<T> implements ContainerStateFluent<T>{

     VisitableBuilder<ContainerStateRunning, ?> running;     VisitableBuilder<ContainerStateTerminated, ?> terminated;     VisitableBuilder<ContainerStateWaiting, ?> waiting;     Map<String, Object> additionalProperties = new HashMap();
public ContainerStateFluentImpl(){
    
}
public ContainerStateFluentImpl( ContainerState instance ){
    this.withRunning(instance.getRunning()); this.withTerminated(instance.getTerminated()); this.withWaiting(instance.getWaiting()); 
}

    public ContainerStateRunning getRunning(){
    return this.running!=null?this.running.build():null;
    }
    public T withRunning( ContainerStateRunning running){
    if (running!=null){ this.running= new ContainerStateRunningBuilder(running); _visitables.add(this.running);} return (T) this;
    }
    public RunningNested<T> withNewRunning(){
    return new RunningNestedImpl<T>();
    }
    public RunningNested<T> withNewRunningLike( ContainerStateRunning item){
    return new RunningNestedImpl<T>(item);
    }
    public RunningNested<T> editRunning(){
    return withNewRunningLike(getRunning());
    }
    public T withNewRunning( String startedAt){
    return withRunning(new ContainerStateRunning(startedAt));
    }
    public ContainerStateTerminated getTerminated(){
    return this.terminated!=null?this.terminated.build():null;
    }
    public T withTerminated( ContainerStateTerminated terminated){
    if (terminated!=null){ this.terminated= new ContainerStateTerminatedBuilder(terminated); _visitables.add(this.terminated);} return (T) this;
    }
    public TerminatedNested<T> withNewTerminated(){
    return new TerminatedNestedImpl<T>();
    }
    public TerminatedNested<T> withNewTerminatedLike( ContainerStateTerminated item){
    return new TerminatedNestedImpl<T>(item);
    }
    public TerminatedNested<T> editTerminated(){
    return withNewTerminatedLike(getTerminated());
    }
    public ContainerStateWaiting getWaiting(){
    return this.waiting!=null?this.waiting.build():null;
    }
    public T withWaiting( ContainerStateWaiting waiting){
    if (waiting!=null){ this.waiting= new ContainerStateWaitingBuilder(waiting); _visitables.add(this.waiting);} return (T) this;
    }
    public WaitingNested<T> withNewWaiting(){
    return new WaitingNestedImpl<T>();
    }
    public WaitingNested<T> withNewWaitingLike( ContainerStateWaiting item){
    return new WaitingNestedImpl<T>(item);
    }
    public WaitingNested<T> editWaiting(){
    return withNewWaitingLike(getWaiting());
    }
    public T withNewWaiting( String message,  String reason){
    return withWaiting(new ContainerStateWaiting(message, reason));
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ContainerStateFluentImpl that = (ContainerStateFluentImpl) o;
if (running != null ? !running.equals(that.running) :that.running != null) return false;
if (terminated != null ? !terminated.equals(that.terminated) :that.terminated != null) return false;
if (waiting != null ? !waiting.equals(that.waiting) :that.waiting != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class RunningNestedImpl<N> extends ContainerStateRunningFluentImpl<RunningNested<N>> implements RunningNested<N>{

        private final ContainerStateRunningBuilder builder;
    
             RunningNestedImpl (){
        this.builder = new ContainerStateRunningBuilder(this);
        }
             RunningNestedImpl ( ContainerStateRunning item){
        this.builder = new ContainerStateRunningBuilder(this, item);
        }
    
            public N and(){
            return (N) ContainerStateFluentImpl.this.withRunning(builder.build());
        }
            public N endRunning(){
            return and();
        }
    
}
    public class TerminatedNestedImpl<N> extends ContainerStateTerminatedFluentImpl<TerminatedNested<N>> implements TerminatedNested<N>{

        private final ContainerStateTerminatedBuilder builder;
    
             TerminatedNestedImpl ( ContainerStateTerminated item){
        this.builder = new ContainerStateTerminatedBuilder(this, item);
        }
             TerminatedNestedImpl (){
        this.builder = new ContainerStateTerminatedBuilder(this);
        }
    
            public N endTerminated(){
            return and();
        }
            public N and(){
            return (N) ContainerStateFluentImpl.this.withTerminated(builder.build());
        }
    
}
    public class WaitingNestedImpl<N> extends ContainerStateWaitingFluentImpl<WaitingNested<N>> implements WaitingNested<N>{

        private final ContainerStateWaitingBuilder builder;
    
             WaitingNestedImpl ( ContainerStateWaiting item){
        this.builder = new ContainerStateWaitingBuilder(this, item);
        }
             WaitingNestedImpl (){
        this.builder = new ContainerStateWaitingBuilder(this);
        }
    
            public N and(){
            return (N) ContainerStateFluentImpl.this.withWaiting(builder.build());
        }
            public N endWaiting(){
            return and();
        }
    
}


}
